package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.SysReport;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2022-06-20
 */
public interface SysReportMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SysReport selectSysReportById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param sysReport 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<SysReport> selectSysReportList(SysReport sysReport);

    /**
     * 新增【请填写功能名称】
     * 
     * @param sysReport 【请填写功能名称】
     * @return 结果
     */
    public int insertSysReport(SysReport sysReport);

    /**
     * 修改【请填写功能名称】
     * 
     * @param sysReport 【请填写功能名称】
     * @return 结果
     */
    public int updateSysReport(SysReport sysReport);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteSysReportById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysReportByIds(Long[] ids);
}
